Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(238)

Unified Diff: chrome/browser/media/webrtc_browsertest_common.h

Issue 227633002: Fixed quality tests after PyAuto test purge. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: .gitignore'ing resource files Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/media/webrtc_browsertest_common.h
diff --git a/chrome/browser/media/webrtc_browsertest_common.h b/chrome/browser/media/webrtc_browsertest_common.h
index 56d3eceb25ed1c6062b22c7a14e5e7e93c102d59..12b130d4422ed3c5c0ed3f7bd949fcf0c36492f5 100644
--- a/chrome/browser/media/webrtc_browsertest_common.h
+++ b/chrome/browser/media/webrtc_browsertest_common.h
@@ -16,17 +16,17 @@ class WebContents;
namespace test {
-// Reference video locations.
+// Reference file locations.
-// Checks if the user has the reference video files, returns true if so.
+// Checks if the user has the reference files directory, returns true if so.
// If the user's checkout don't have these dirs, they need to configure their
-// .gclient as described in kAdviseOnGclientSolution. The reason for this is
-// that we don't want to burden regular chrome devs with downloading these
-// sizable reference files by default.
+// .gclient as described in chrome/test/data/webrtc/resources/README. The reason
+// for this is that we don't want to burden regular chrome devs with downloading
+// these sizable reference files by default.
bool HasReferenceFilesInCheckout();
-// Retrieves the reference video dir, to which file names can be appended.
-base::FilePath GetReferenceVideosDir();
+// Retrieves the reference files dir, to which file names can be appended.
+base::FilePath GetReferenceFilesDir();
extern const base::FilePath::CharType kReferenceFileName360p[];
extern const base::FilePath::CharType kYuvFileExtension[];
« no previous file with comments | « chrome/browser/media/chrome_webrtc_video_quality_browsertest.cc ('k') | chrome/browser/media/webrtc_browsertest_common.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698